"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const practical_logger_core_1 = require("@offirmo/practical-logger-core");
const consts_1 = require("./consts");
const _1 = require(".");
describe(`${consts_1.LIB} - index`, () => {
    describe('createLogger()', () => {
        it('should work with no params', () => {
            const logger = _1.createLogger();
            logger.fatal('Hello!');
        });
        it('should work with all params', () => {
            const logger = _1.createLogger({
                name: 'test',
                suggestedLevel: 'error',
                forcedLevel: 'silly',
                commonDetails: {
                    foo: 'bar'
                },
                sinkOptions: {},
            });
            logger.fatal('Hello!');
        });
        it('should correctly display all log levels', () => {
            const logger = _1.createLogger({
                name: 'demo',
                forcedLevel: 'silly',
            });
            [...practical_logger_core_1.ALL_LOG_LEVELS].reverse().forEach(ll => {
                if (ll === 'warning')
                    return; // alias
                logger[ll]('Something happened', { foo: 42 });
            });
        });
        it('should allow passing sink options', () => {
            const logger = _1.createLogger({
                name: 'test',
                sinkOptions: {
                    displayTime: true,
                },
            });
            logger.fatal('Hello!');
        });
        it('should allow passing a custom sink', () => {
            const sink = (payload) => void {
            // nothing
            };
            const logger = _1.createLogger({
                name: 'test',
                sinkOptions: {
                    sink,
                },
            });
            logger.fatal('Hello!');
        });
    });
});
//# sourceMappingURL=index_spec.js.map