"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
/* eslint-disable no-console */
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const common_1 = require("./common");
const COMMON_ERROR_FIELDS = [
    // standard fields
    // https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Error/prototype
    'name',
    'message',
    // quasi-standard
    // https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Error/prototype
    'stack',
    // standard in node
    'code',
    // https://nodejs.org/dist/latest/docs/api/errors.html#errors_node_js_error_codes
    // non standard but widely used
    'statusCode',
    'shouldRedirect',
    'framesToPop',
    // My (Offirmo) extensions
    'details',
    'SEC',
    '_temp',
];
function displayErrProp(errLike, prop) {
    if (prop === 'details') {
        const details = errLike.details;
        console.error(chalk_1.default.red(chalk_1.default.dim(`🔥  ${prop}:`)));
        Object.entries(details).forEach(([key, value]) => {
            console.error(chalk_1.default.red(chalk_1.default.dim(`    ${key}: "`) + value + chalk_1.default.dim('"')));
        });
    }
    else
        console.error(chalk_1.default.red(chalk_1.default.dim(`🔥  ${prop}: "`) + errLike[prop] + chalk_1.default.dim('"')));
}
function displayError(errLike = {}) {
    console.error(chalk_1.default.red(`🔥🔥🔥🔥🔥🔥🔥  ${chalk_1.default.bold(errLike.name || 'Error')} 🔥🔥🔥🔥🔥🔥🔥`));
    const displayedProps = new Set();
    displayedProps.add('name');
    if (errLike.message) {
        displayErrProp(errLike, 'message');
        displayedProps.add('message');
    }
    if (errLike.details) {
        displayErrProp(errLike, 'details');
        displayedProps.add('details');
    }
    if (errLike.logicalStack) {
        displayErrProp(errLike, 'logicalStack');
        displayedProps.add('logicalStack');
    }
    COMMON_ERROR_FIELDS.forEach(prop => {
        if (prop in errLike && !displayedProps.has(prop)) {
            displayErrProp(errLike, prop);
        }
    });
}
function createSink(options = {}) {
    const displayTime = options.displayTime || false;
    return (payload) => {
        const { level, name, msg, time, details, err } = payload;
        const prettified_details = JSON.stringify(details);
        const line = ''
            // TODO evaluate if time display is needed
            + (displayTime
                ? (chalk_1.default.dim(String(time)) + ' ')
                : '')
            + common_1.LEVEL_TO_ASCII[level]
            + '› '
            + common_1.LEVEL_TO_STYLIZE[level](''
                + name
                + (name ? '›' : '')
                + (msg ? ' ' : '')
                + msg)
            + (prettified_details !== '{}'
                ? (' ' + prettified_details)
                : '');
        console.log(line); // eslint-disable-line no-console
        if (err)
            displayError(err);
    };
}
exports.createSink = createSink;
exports.default = createSink;
//# sourceMappingURL=to-console.js.map